// Copyright 2025 "Johan Maasing" <johan@zoom.nu>
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
package nu.zoom.dsl.ast;

import nu.zoom.dsl.parser.EndpointsLexer;
import nu.zoom.dsl.parser.EndpointsParser;
import org.antlr.v4.runtime.CharStreams;
import org.antlr.v4.runtime.CommonTokenStream;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Path;

public class ParserWrapper {
    public static DocumentNode parse(Path sourcePath) throws IOException {
        var ins = CharStreams.fromPath(sourcePath, StandardCharsets.UTF_8);
        EndpointsLexer lexer = new EndpointsLexer(ins);
        EndpointsParser parser = new EndpointsParser(new CommonTokenStream(lexer));
        var document = parser.document();
        var astTransformer = new EndpointsVisitorTransformer();
        astTransformer.visit(document);
        return new DocumentNode(astTransformer.getConfig(), astTransformer.getDataTypes(), astTransformer.getEndpoints());
    }
}
